/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: InstallationServiceMBean.java 154 2006-03-27 15:30:10Z ofabre $
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.jbi.management.admin;

import java.util.Map;

import javax.jbi.JBIException;
import javax.jbi.messaging.MessageExchange;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.management.MBeanServer;
import javax.management.ObjectName;

import org.ow2.petals.container.lifecycle.ComponentLifeCycle;
import org.ow2.petals.container.lifecycle.Installer;
import org.ow2.petals.container.lifecycle.LifeCycleAbstract;
import org.ow2.petals.container.lifecycle.ServiceAssemblyLifeCycle;
import org.ow2.petals.container.lifecycle.SharedLibraryLifeCycle;
import org.ow2.petals.jbi.management.MBeanNames;
import org.ow2.petals.jbi.management.ManagementException;
import org.ow2.petals.kernel.api.server.PetalsException;

/**
 * The <code>AdminServiceMBean</code> interface extends
 * {@link javax.jbi.management.AdminServiceMBean} to add Lifecycle Management
 * capabilities through the LifeCycleManagerImpl.
 *
 * @author ofabre
 *
 */
public interface AdminServiceMBean extends
    javax.jbi.management.AdminServiceMBean {

    /**
     * Get the service description for a endpoint of a component
     *
     * @param componentName
     *            name of the component
     * @param endpoint
     *            endpoint
     * @return String representation of a DOM Document containing the service
     *         description
     */
    String getServiceDescription(String componentName, ServiceEndpoint endpoint)
        throws PetalsException;

    /**
     * Check if a message exchange is okay with a provider
     *
     * @param componentName
     * @param providerEP
     * @param exchange
     * @return
     * @throws JBIException
     *             If no component is found with this component name
     */
    boolean isExchangeWithProviderOkayForComponent(String componentName,
        ServiceEndpoint internalEndpoint, MessageExchange exchange)
        throws JBIException;

    /**
     * Check if a message exchange is okay with a consumer
     *
     * @param componentName
     * @param internalEndpoint
     * @param exchange
     * @return
     * @throws JBIException
     *             If no component is found with this component name
     */
    boolean isExchangeWithConsumerOkayForComponent(String componentName,
        ServiceEndpoint internalEndpoint, MessageExchange exchange)
        throws JBIException;

    ObjectName getAdminServiceMBeanName() throws ManagementException;

    /**
     * Find the {@link LifeCycleAbstract} of a JBI Installable Component by its
     * unique name.
     *
     * @param name
     *            the name of the engine or binding component; must be non-null
     *            and non-empty
     * @return the {@link LifeCycleAbstract} of the component, or
     *         <code>null</code> if there is no such component with the given
     *         <code>name</code>
     */
    ComponentLifeCycle getComponentLifeCycleByName(String name);

    ObjectName getDeploymentServiceMBeanName() throws ManagementException;

    ObjectName getInstallationServiceMBeanName() throws ManagementException;

    ObjectName getInstallerByName(String name);

    MBeanNames getMBeanNames();

    MBeanServer getMBeanServer();

    ServiceAssemblyLifeCycle getServiceAssemblyByName(String saName);

    SharedLibraryLifeCycle getSharedLibraryByName(String slName);

    Map<ObjectName, ComponentLifeCycle> getBindingCompoLifeCycles();

    Map<ObjectName, ComponentLifeCycle> getEngineCompoLifeCycles();

    Installer getInstallerMBeanByName(ObjectName name);

    Map<ObjectName, Installer> getInstallers();

    Map<String, ServiceAssemblyLifeCycle> getServiceAssemblyLifeCycles();

    Map<String, SharedLibraryLifeCycle> getSharedLibraryLifeCycles();

    ObjectName registerBindingComponent(ComponentLifeCycle lifeCycle)
        throws ManagementException;

    ObjectName registerEngineComponent(ComponentLifeCycle lifeCycle)
        throws ManagementException;

    ObjectName registerInstaller(Installer installerMBean)
        throws ManagementException;

    void registerServiceAssembly(String saName,
        ServiceAssemblyLifeCycle serviceAssemblyLifeCycle);

    void registerSharedLibrary(String slName,
            SharedLibraryLifeCycle sharedLibraryLifeCycle);

    void unregisterBindingComponent(ObjectName name) throws ManagementException;

    void unregisterEngineComponent(ObjectName name) throws ManagementException;

    void unregisterInstaller(ObjectName name) throws ManagementException;

    void unregisterServiceAssembly(String saName) throws ManagementException;

    void unregisterSharedLibrary(String slName) throws ManagementException;

}
