/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.jbi.management.task;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.util.HashMap;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jbi.management.task.installation.InstallationUtils;
import org.ow2.petals.util.LoggingUtil;

/**
 * This task creates success file in workdir <br/> Inputs : {@link Jbi}, archive
 * {@link URI} <br/>
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class SuccessTask extends AbstractFileManipulationTask {

    /**
     * logger wrapper
     */
    protected LoggingUtil log;

    public SuccessTask(String petalsInstallDirectory, LoggingUtil log) {
        super(petalsInstallDirectory);
        this.log = log;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#execute(java.util.HashMap)
     */
    public void execute(HashMap<String, Object> context) throws Exception {

        URI installRoot = (URI) context.get(TaskContextConstants.INSTALL_ROOT);

        Jbi descriptor = (Jbi) context.get(TaskContextConstants.DESCRIPTOR);

        /*
         * Create success file in workdir
         */
        try {
            createSuccessFile(installRoot);
        } catch (IOException e) {
            // nothing to do, just log
            log.warning("Success file can't be created " + "but component correctly installed: "
                    + InstallationUtils.getComponentNameFromDescriptor(descriptor));
        }

    }

    /**
     * Create a ".success" file in the work directory. The name of the new file
     * is the name of the "file" parameter with the suffix ".succes"
     * 
     * @param systemStateFile
     *      file from which the name is computed
     * @throws IOException
     *      If an error occurs at the file creation
     */
    private void createSuccessFile(URI installRoot) throws IOException {
        File file = new File(installRoot);
        new File(getWorkDirectory(), file.getParentFile().getName() + ".success").createNewFile();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#undo(java.util.HashMap)
     */
    public void undo(HashMap<String, Object> context) {
        // Last task, nothing to do

    }

}
