/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: RemoveAllConnectionsTask.java 154 10 oct. 06 ofabre $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task.deployment.undeploy;

import java.util.HashMap;

import javax.xml.namespace.QName;

import org.ow2.petals.container.lifecycle.ServiceAssemblyLifeCycle;
import org.ow2.petals.jbi.descriptor.original.generated.Connection;
import org.ow2.petals.jbi.descriptor.original.generated.Connections;
import org.ow2.petals.jbi.descriptor.original.generated.ServiceAssembly;
import org.ow2.petals.jbi.management.task.deployment.DeploymentContextConstants;
import org.ow2.petals.jbi.messaging.registry.EndpointRegistry;
import org.ow2.petals.processor.Task;

/**
 * This task remove all connections from the registry<br/> Inputs :
 * {@link ServiceAssemblyLifeCycle} <br/>
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class RemoveAllConnectionsTask implements Task {

    protected EndpointRegistry EndpointRegistry;

    public RemoveAllConnectionsTask(EndpointRegistry EndpointRegistry) {
        super();
        this.EndpointRegistry = EndpointRegistry;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#execute(java.util.HashMap)
     */
    public void execute(HashMap<String, Object> context) throws Exception {

        ServiceAssemblyLifeCycle lifeCycle = (ServiceAssemblyLifeCycle) context
                .get(DeploymentContextConstants.SA_LIFECYCLE);

        removeConnections(lifeCycle);

    }

    /**
     * Remove all connections registered during the SA deployment process
     * 
     * @param saLifeCycle
     *            the service assembly life cycle
     * @throws Exception
     *             if problem occurs during the deletion of a specific
     *             connection
     */
    protected void removeConnections(ServiceAssemblyLifeCycle saLifeCycle) throws Exception {
        ServiceAssembly saDesc = saLifeCycle.getServiceAssembly();
        Connections connections = saDesc.getConnections();
        if (connections != null) {
            for (Connection connection : connections.getConnection()) {
                QName consInterface = connection.getConsumer().getInterfaceName();
                QName consService = connection.getConsumer().getServiceName();
                String consEndpoint = connection.getConsumer().getEndpointName();
                QName provService = connection.getProvider().getServiceName();
                String provEndpoint = connection.getProvider().getEndpointName();

                if (provEndpoint != null && provService != null) {
                    if (consInterface != null) {
                        EndpointRegistry.deleteConnection(consInterface, provService, provEndpoint);
                    } else if (consService != null && consEndpoint != null) {
                        EndpointRegistry.deleteConnection(consService, consEndpoint, provService,
                                provEndpoint);
                    }
                }
            }
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#undo(java.util.HashMap)
     */
    public void undo(HashMap<String, Object> context) throws Exception {
        // Nothing to do
    }

}
