/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task.installation.install.sl;

import java.io.File;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jbi.descriptor.original.generated.Jbi.SharedLibrary;
import org.ow2.petals.jbi.management.admin.AdminServiceMBean;
import org.ow2.petals.jbi.management.task.AbstractCheckPackageTask;
import org.ow2.petals.jbi.management.task.installation.InstallationUtils;
import org.ow2.petals.jbi.management.util.PackageHelper;
import org.ow2.petals.kernel.api.server.PetalsException;
import org.ow2.petals.util.LoggingUtil;
import org.ow2.petals.util.StringHelper;

/**
 * This task checks the validity of the Shared Library package.
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class SLCheckPackageTask extends AbstractCheckPackageTask {

    /**
     * JBI Admin Service :: Admin Service
     */
    private AdminServiceMBean adminService;

    public SLCheckPackageTask(LoggingUtil log, PackageHelper packageHandler,
            AdminServiceMBean adminService) {
        super(log, packageHandler);
        this.adminService = adminService;
    }

    /**
     * Check the validity of the Shared Library archive
     * 
     * @param descriptor
     *            the shared lib <code>Jbi</code>
     * @param filePackage
     *            the service assembly package root
     * @return {@code true} if checking is successful and {@code false} otherwise
     * @throws PetalsException
     * @throws ComponentCheckingException
     */
    @Override
    protected void checkPackage(Jbi descriptor, File filePackage) throws PetalsException {

        // check if JBI descriptor has a shared-library element
        SharedLibrary sl = descriptor.getSharedLibrary();
        if (sl == null) {
            throw new PetalsException("The shared-library production element was not found in "
                    + "JBI Descriptor within installation package: "
                    + filePackage.getAbsolutePath());
        } else {
            // check if it is already loaded by package uuid
            String slName = sl.getIdentification().getName();

            if (StringHelper.isNullOrEmpty(slName)) {
                throw new PetalsException(
                        "The shared library name must be non null and non empty :"
                                + filePackage.getAbsolutePath());
            }

            if (isSharedLibraryLoaded(slName)) {
                throw new PetalsException("Other shared library package already exists loaded in "
                        + "the component framework: " + slName);
            } else {
                // Check the classpath element of the shared library
                InstallationUtils.checkClassPathElements(filePackage, sl
                        .getSharedLibraryClassPath().getPathElement());
            }

        }
    }

    private boolean isSharedLibraryLoaded(String slName) {
        return adminService.getSharedLibraryByName(slName) != null;
    }

    @Override
    protected String extractEntityName(Jbi descriptor) {
        return descriptor.getSharedLibrary().getIdentification().getName();
    }

}
