/**
 * PETALS - PETALS Services Platform. Copyright (c) 2008 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.messaging.routing.module;

import org.ow2.petals.jbi.component.context.ComponentContextImpl;
import org.ow2.petals.jbi.messaging.exchange.MessageExchangeImpl;
import org.ow2.petals.jbi.messaging.routing.RoutingException;

/**
 * The module interface definition 
 * 
 * @author Christophe HAMERLING - eBM WebSourcing
 * @since 2.2
 * 
 */
public interface Module extends LifeCycle {
    /**
     * 
     * @return
     */
    boolean isEngaged();

    /**
     * Send the message into the NMR.
     * 
     * @param source
     *            the source
     * @param exchange
     *            the exchange
     * @param timeOut
     *            timeout of the message (in ms). 0 for no timeout
     * @throws RoutingException
     *             impossible to send the message
     */
    void send(ComponentContextImpl source, MessageExchangeImpl exchange, long timeOut)
            throws RoutingException;

    /**
     * Send the message synchronously into the NMR.
     * 
     * @param source
     *            the source
     * @param exchange
     *            the exchange
     * @param timeOut
     *            timeout of the message (in ms). 0 for no timeout
     * 
     * @return the response exchange if received, or <code>null</code> if the
     *         timeout is reached
     * 
     * @throws RoutingException
     *             impossible to process a synchronous send
     */
    MessageExchangeImpl sendSync(ComponentContextImpl source, MessageExchangeImpl exchange,
            long timeOut) throws RoutingException;

    /**
     * Try to receive a message from MNR if there is any and return it.
     * 
     * @param source
     *            The source component context
     * @param timeoutMS
     *            The timeout to receive the incoming message. If equals to -1,
     *            the timeout is infinite
     * 
     * @return The message exchange retrieve from the <code>Transporter</code>
     * 
     * @throws RoutingException
     *             impossible to receive the message
     */
    MessageExchangeImpl receive(ComponentContextImpl source, long timeoutMS)
            throws RoutingException;
}
