/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: PetalsAdminServiceMBean.java 16:40:52 alouis $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.kernel.admin;

import java.util.Map;
import java.util.Set;

import org.ow2.petals.jmx.api.IPetalsAdminService;
import org.ow2.petals.kernel.api.server.PetalsException;

/**
 * This class is a manager of JMX server. It is used to get a connection to a
 * JMX Server on a distant container.
 * 
 * @author ddesjardins, rnaudin - eBMWebsourcing
 */
public interface PetalsAdminServiceMBean extends IPetalsAdminService {

    /**
     * Retrieve the collection of containers, sub-domains and domain
     * configurations.
     * 
     * @return a Set of containers, sub-domains and domain configurations in
     *         key/value form
     * @throws PetalsException
     */
    Set<Map<String, String>> retrieveTopology() throws PetalsException;

    /**
     * Unload the container from the Petals global environment. All
     * ServiceAssemblies, Components and Share Libraries are stopped, shutdown,
     * and uninstalled. All registered Endpoints are deactivated. Then the
     * container is removed from the domain.
     * 
     * @throws Exception
     */
    void shutdownContainer() throws Exception;

    /**
     * Stop the container. The container is still visible in the Petals global
     * environment, but marked as 'stopped'. The registered Endpoints are still
     * visible,too.
     * 
     * @throws Exception
     */
    void stopContainer() throws Exception;
}
