/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.kernel.interceptors.stat;

/**
 * This class gives the sta tistic information about the method used.
 *
 * @author Nicolas SALATGE - eBMWebSourcing
 *
 */
public class InfoStat {

    /**
     * the method name.
     */
    private String methodName = null;

    /**
     * the thread name.
     */
    private String threadName = null;

    /**
     * the date when the information has benn stored.
     */
    private String date = null;

    /**
     * the begin date in long.
     */
    private long beginDateInLong = 0;

    /**
     * the time passed in the method (in nano second).
     */
    private long time = 0;

    /**
     * the default constructor.
     *
     * @param m
     *            the method name
     * @param tn
     *            the thread name
     * @param bd
     *            the date in long
     * @param d
     *            the date
     * @param t
     *            the time (in nano second)
     */
    public InfoStat(final String m, final String tn, final long bd,
            final String d, final long t) {
        this.methodName = m;
        this.threadName = tn;
        this.beginDateInLong = bd;
        this.date = d;
        this.time = t;
    }

    /**
     * get the method name.
     *
     * @return the method name
     */
    public String getMethodName() {
        return this.methodName;
    }

    /**
     * get the thread name.
     *
     * @return the thread name
     */
    public String getThreadName() {
        return this.threadName;
    }

    /**
     * get the date.
     *
     * @return the date
     */
    public String getDate() {
        return this.date;
    }

    /**
     * get the time (in nano second).
     *
     * @return the time (in nano second)
     */
    public long getTime() {
        return this.time;
    }

    public long getBeginDateInLong() {
        return this.beginDateInLong;
    }
}
